*********
Mopidy-Cd
*********

`Mopidy <http://www.mopidy.com/>`_ extension for playing music from Audio CD




Installation
============

Install by running::

      sudo pip install Mopidy-Cd

Or, if available, install the Debian/Ubuntu package from `apt.mopidy.com
<http://apt.mopidy.com/>`_.


Configuration
=============

No configuration needed


Project resources
=================

- `Source code <https://github.com/asartori/mopidy-cd>`_
- `Issue tracker <https://github.com/asartori/mopidy-cd/issues>`_
- `Development branch tarball <https://github.com/asartori/mopidy-cd/tarball/master#egg=Mopidy-Cd-dev>`_


Changelog
=========

v0.1.0 (2015-01-20)
-------------------

- Initial release.
